Core–Shell Bimetallic Nanoparticles Robustly Fixed on the Outermost Surface of Magnetic Silica Microspheres | Scientific Reports
Author: Hye Hun Park
Description: The major challenges in practically utilising the immense potential benefits of nanomaterials are controlling aggregation, recycling the nanomaterials and fabricating well-defined nanoparticulate materials using innovative methods. We present a novel innovative synthetic strategy for core–shell bimetallic nanoparticles that are well-defined, ligand-free and robustly fixed on the outermost surface of recyclable magnetic silica microspheres. The strategy includes seeding, coalescing the seeds to cores and then growing shells from the cores on aminopropyl-functionalised silica microspheres so that the cores and aminopropyl moieties are robustly embedded in the shell materials. The representative Au–Ag bimetallic nanoparticles fixed on the microsphere showed excellent catalytic performance that remained consistent during repeated catalytic cycles.
Keywords: Catalyst synthesis
Date: 2013-03-20

Skip to main content

Thank you for visiting nature.com. You are using a browser version with limited support for CSS. To obtain the best experience, we recommend you use a more up to date browser (or turn off compatibility mode in Internet Explorer). In the meantime, to ensure continued support, we are displaying the site without styles and JavaScript.

Advertisement

Core–Shell Bimetallic Nanoparticles Robustly Fixed on the Outermost Surface of Magnetic Silica Microspheres
Download PDF

- Open Access
- Published: 20 March 2013

# Core–Shell Bimetallic Nanoparticles Robustly Fixed on the Outermost Surface of Magnetic Silica Microspheres

- Hye Hun Park1,
- Kyoungja Woo1 &
- Jae-Pyoung Ahn2

Scientific Reports volume 3, Article number: 1497 (2013) Cite this article

- 355 Accesses

- 34 Citations

- 3 Altmetric

- Metrics details

### Subjects

- Catalyst synthesis
- Composites
- Heterogeneous catalysis
- Nanoparticles

## Abstract

The major challenges in practically utilising the immense potential benefits of nanomaterials are controlling aggregation, recycling the nanomaterials and fabricating well-defined nanoparticulate materials using innovative methods. We present a novel innovative synthetic strategy for core–shell bimetallic nanoparticles that are well-defined, ligand-free and robustly fixed on the outermost surface of recyclable magnetic silica microspheres. The strategy includes seeding, coalescing the seeds to cores and then growing shells from the cores on aminopropyl-functionalised silica microspheres so that the cores and aminopropyl moieties are robustly embedded in the shell materials. The representative Au–Ag bimetallic nanoparticles fixed on the microsphere showed excellent catalytic performance that remained consistent during repeated catalytic cycles.

Download PDF

## Introduction

The major challenges in practically utilising the immense potential benefits of nanomaterials are controlling aggregation and recycling the nanomaterials as well as fabricating well-defined nanoparticulate materials using innovative methods. The ligands themselves, which have been added to prevent nanoparticle aggregations, are problematic in the catalytic applications of nanoparticles1,2,3,4. However, aggregation control and recycling, even without ligands, are relatively easy in microspheres (including sub-microspheres), because microspheres are easily separable and re-dispersible5,6,7,8. Therefore, the robust fixation of ligand-free well-defined nanoparticles on the outermost surface of microspheres can pave the way for the beneficial utilisation of nanomaterials. Well-defined core–shell bimetallic nanoparticles robustly fixed on the microspheres are of especially great interest because their synthesis and characterisation are highly challenging despite the unique electronic properties and superior catalytic activities of these materials9,10,11,12,13,14,15,16.

The functionalization of silica or polymer microspheres with –NH2 or other groups has been used to attach the metal nanoparticles, as well as to control the direct growth of nanoparticles17,18,19,20,21,22. The resulting composites showed comparable catalytic activity to and improved recyclability over the corresponding free nanoparticles. However, their catalytic performance and the yields of the catalytic reactions gradually decreased to a substantial extent over repeated cycles, due to the detachment of the nanoparticles from the spheres4,20,21. A polymer or etched-silica shield was elaborately constructed on the surface of the composite and the resultant nanosystems exhibited comparable catalytic property and highly improved recyclability4,21,22. Their catalytic performance still decreased gradually but to a small extent over a series of repeated catalytic reactions, despite the complicated and elaborate synthetic process required21. Moreover, most studies have been focused on homometallic nanoparticles weakly attached to the microspheres.

For the first time, we present a novel innovative synthetic strategy for core–shell bimetallic nanoparticles that are well-defined, ligand-free and robustly fixed on the outermost surface of magnetically recyclable silica microspheres (MSM). The strategy includes seeding metal seeds, coalescing the seeds to cores and then growing shells directly from the cores on the aminopropyl (AP)-functionalised MSM (AP-MSM) so that the cores and AP moieties are robustly embedded in the shell materials. The representative and least expensive noble material, Au–Ag core–shell bimetallic nanoparticles fixed on MSM, consistently showed excellent catalytic performance upon repeated catalytic cycles of a benchmark reaction23 for the noble metal nanocatalysts. The current synthetic strategy was extended to Au–Pd core–shell bimetallic nanoparticles fixed on MSM and may pave the way for the beneficial utilisation of nanomaterials.

## Results

### Synthetic strategy

Figure 1 shows our seeding, coalescing and growing (SCG) strategy for core–shell bimetallic nanoparticles robustly fixed on the outermost surface of silica microspheres (SM), including MSM. In most cases, we used MSM that consisted of a superparamagnetic Fe3O4 core and SiO2 shell [Fig. S1 of Supplementary Information (SI)] due to its amenability to magnetic separation. The Fe3O4 core (~300 nm) consists of many ~10 nm sized Fe3O4 particles and is surrounded by a silica shell (~100 nm thickness), when synthesized according to the method published in the literature21,24. However, the current SCG strategy is also applicable to SM, as will be described later, because its surface chemistry is exactly the same as that of MSM and they are easily separated by normal centrifugation.

Figure 1

Schematic representation of the SCG strategy for core-shell bimetallic nanoparticles robustly fixed on the outermost surface of magnetic silica microsphere (MSM).

In the seeding step, 1–2 nm Au seeds are self-assembled on the aminopropyl (AP)-functionalised MSM. In the coalescing step, excess metal ions displace the small (~1 nm) Au seeds, which coalesce to 2–3 nm Au cores and are multi-bonded with more AP moieties. In the growing step, the shells are formed so that the cores and AP moieties are embedded in the shell materials.

Full size image

As a proof-of-principle, AgNO3 and HAuCl4 solutions were each added to Au-seeded AP-MSM solutions with gentle stirring and then, formaldehyde was added as a mild reducing agent25 to yield bimetallic Au–Ag core–shell nanoparticles and homometallic Au–Au nanoparticles, respectively, grown from the Au cores on the AP-MSM, so that the Au cores and AP moieties are embedded in the shell materials. The extendibility of the SCG strategy was demonstrated by synthesizing bimetallic Au–Pd core–shell nanoparticles fixed on the MSM using PdCl2 solution and L-ascorbic acid instead of AgNO3 solution and formaldehyde, respectively, while keeping the other conditions the same. These composites will be designated nAg/Au@MSM (dn), nAu/Au@MSM (en) and nPd/Au@MSM (fn), where, n indicates nanoparticles; n ranges from 1 to 3 as the particles continue growing and should be differentiated from the corresponding nAg@MSM, nAu@MSM and nPd@MSM (Fig. S2), which are prepared without the Au-seeding process.

### Structural analysis

Figure 2 shows various electron microscopic images of the materials generated according to the SCG strategy. The TEM image b shows homogeneously self-assembled 1–2 nm Au seeds on the AP-MSM (a). After the addition of Ag+ ions, the Au seeds coalesce, yielding 2–3 nm Au cores, which are shown in image c. In the growing step, adding more metal ions yielded larger nanoparticles on the MSM, as indicated by the n values of 1 to 3 for all of the samples dn, en and fn; the particle size distributions were relatively homogeneous as shown in the histograms of Fig. S3. The elemental analysis of dn samples gave Au:Ag atomic ratios of (d1) 1:4, (d2) 1:10 and (d3) 1:16 and their combined (Au and Ag) weight fractions in the composite system were 3.85, 6.54 and 10.7% respectively. In the images of e3 and f3, the Au–Au and Au–Pd nanoparticles have merged with their neighboring nanoparticles. The SEM image (Fig. 2g~i) of each composite system shows relatively homogeneous nanoparticle size and surface coverage.

Figure 2

TEM and SEM images of various composite systems.

(a) AP-MSM. (b) Au-seeded MSM. (c) Au seeds-coalesced MSM. (d1–d3) nAg/Au@MSM. (e1–e3) nAu/Au@MSM. (f1–f3) nPd/Au@MSM, with further growing from 1 to 3. (g) d2. (h) e2. (i) f2. (The 2nd and 3rd row shows partially magnified image of the 1st row and of the en and fn series, respectively.).

Full size image

Figure 3 shows a detailed structural analysis of composite system d2 by HRTEM/HRSTEM, Cs-aberration-corrected STEM and Z-contrast HAADF imaging. Some nanoparticles torn away from d2 by etching reveal the distinct bimetallic contrast of Au cores and the Ag shell in Figs. 3a and b. Milling of the epoxy resin embedding d2 using a focused ion beam (FIB) at room temperature induced serious damage to or evaporation of the Ag shell (Fig. 3c). Along the indicated line in the magnified image d, the EDS line profile shown in e was obtained. The less damaged Au-Ag core-shell images of the intact system (Figs. 3f and g) were obtained by milling the resin under liquid N2 conditions.

Figure 3

TEM/HRTEM/Z-contrast HAADF-STEM images and EDS line profile of bimetallic nanoparticles and composite systems.

(a–b) Au–Ag nanoparticles torn away from MSM by etching. (c–g) FIB-milled nAg/Au@MSM (d2) after being embedded in epoxy resin.

Full size image

### Catalytic properties and reusability

Figure 4 shows the linear relationship between ln(Ct/C0) and time t for the reductions of p-nitrophenol (Nip) to p-aminophenol (Amp) by NaBH4, where Ct and C0 represent the concentration of Nip at time t and 0, respectively. The apparent rate constant k at room temperature was calculated from the equation ln(Ct/C0) = − kt and the turn over frequency (TOF) was calculated based on 90% conversion and the number of total surface atoms of the Ag nanocatalysts. The resultant data are summarised in Table S1 for five runs, which used magnetically recovered d2 and e2 from the previous run.

Figure 4

Relationship of ln(Ct/C0) and reaction time for the catalysed reduction of p-nitrophenol by composite systems over repeated cycles.

(a) nAg/Au@MSM (d2). (b) nAu/Au@MSM (e2).

Full size image

## Discussion

For the seeding step, AP-MSM (~500 nm) and Au seeds (1–2 nm) were prepared independently according to published methods21,26,27 (SI). The as-prepared Au seeds are protected by tetrakis(hydroxymethyl)phosphonium chloride (THPC) and are well-dispersed without aggregation. Simply mixing AP-MSM with excess Au seeds yields homogeneously self-assembled Au seeds on the AP-MSM. The negatively charged THPCs on the Au seed play an important role in the even distribution of Au seeds on the AP-MSM due to electrostatic repulsion. The NH2 moieties dangling from the MSM surface are known to have kinetically strong chemical affinity for Ag and Au, especially for Au nanoparticles28,29. Therefore, we utilised NH2 moieties for attaching Au seeds. The unbound excess Au seeds are easily removed by magnetic decantation and the Au-seeded MSM are stably dispersed in water by sonication for a few seconds.

For the shell materials, we have chosen Ag, the least expensive noble metal, which is well known to make alloys30 with Au to form core–shell bimetallic nanoparticles while minimising separate nucleation during the growth process. Moreover, Au–Ag core–shell bimetallic nanoparticles are known to exhibit improved catalytic performance relative to Au or Ag homometallic nanoparticles15,16. Au was also chosen to grow homometallic nanoparticles as a comparison. In addition, Pd was chosen to investigate the extendibility of the SCG strategy because Pd is quite expensive and known to make important Au–Pd core–shell bimetallic nanocatalysts9,11,12,13,14. Moreover, these choices can facilitate predictions of nanoparticle growth patterns because Ag and Pd show, respectively, weaker and stronger chemical affinity for NH2 than Au28,29,31. Here, we assumed that the number of NH2 moieties bonded to a single Au seed increases with the size of the Au seed and that the area occupied by a single AP moiety32 is ~0.69 nm2. For the coalescing step, large excess metal ions are added. The metal ions can also make a complex with the NH2 moieties of AP-MSM. Thus, the small (~1 nm) Au seeds on the AP-MSM can be displaced by metal ions whereas relatively larger (~2 nm) Au seeds, which bond with more NH2 moieties, remain attached. The small Au seeds, displaced from NH2 moieties, are likely to collide and coalesce with a neighboring Au seed to form a sintered core that is then large (2–3 nm) enough to make strong multi-bonds with more NH2 moieties. Therefore, less closely assembled 2–3 nm cores are formed on the AP-MSM. This coalescing step can be illustrated as in Fig. 1 and is observed by comparing the TEM images taken before and after coalescence (Figs. 2b and c for a small area and Fig. S4 for the larger area). The particles on the AP-MSM are slightly larger after coalescence. The coalescence of Au seeds to cores in Ag+ solution seems to progress further than in Pd2+ solution due to kinetic effects and yields less closely assembled cores. This difference provides information concerning the difference between d3 and f3, as will be discussed later.

For the growing step, the appropriate mild reducing agent is added. The reduced metal component will grow around the Au cores. However, the multi-bonds between the Au core and NH2 moieties will indicate the growth direction of the shell materials further upward and sideways rather than downward because there is limited space (only AP unit distance) under the Au cores. Therefore, as the shells grow, they are expected to be eccentric or hemisphere-shaped cores–shell bimetallic nanoparticles rather than concentric ones. Also, the AP moieties are expected to be embedded by the growing shell and this type of embedding, together with the strong multi-bonds between core and amines, can be the origin of robust fixation of core–shell bimetallic nanoparticles on the MSM. With more metal ions, the nanoparticles are likely to grow further and gradually merge with the neighboring nanoparticles.

Assuming that the growth of metal nanoparticles on the AP-MSM surface is strongly influenced by the presence of the Au seeds, we examined the dependence of dn, en and fn synthesis on Au seeding in greater detail. Considering that NH2 moieties themselves might act as nucleation sites, direct growth of metal nanoparticles from AP-MSM, without the Au-seeding process, was tried to yield nAg@MSM, nAu@MSM and nPd@MSM. The overall procedures were kept the same except omitting the Au-seeding step. Given that NH2 moieties on the MSM surface are able to bond with metal nanoparticles28,29,31, we were surprised to observe only several Ag and Au nanoparticles attached to MSM (Fig. S2). Pd nanoparticles showed more frequent but inhomogeneous attachment. Moreover, free nanoparticles detached from these composites were observed during repeated recovery processes. This control experiment strongly suggests that Au seeding is a prerequisite process in the current SCG strategy.

In Fig. 2, the Au–Ag bimetallic nanoparticles show similar growth behaviour at the early stages 1 and 2 but somewhat different behaviour at stage 3. The Au–Ag nanoparticle shape of d3 still looks like a hemisphere. Ag, Au and Pd shells appear to grow from the Au cores. However, Ag shells tend to grow upwards, whereas Au and Pd shells tend to grow sideways. This observation is in agreement with the previous report25 that Ag metal exhibits island-type growth, whereas Au and Pd metals exhibit lateral growth; the tendency for lateral growth is higher in Pd than Au. Moreover, less coalescence of Au seeds to cores occurs in Pd2+ solution than in Ag+ solution; as a result, the cores are more closely assembled in Pd2+ solution. Thus, the growing Pd shells tend to make a closed micro-shell, as shown in Fig. 2f3. Therefore, the shell thickness trend appears to be Ag > Au > Pd. The SEM images (Fig. S5–7) of many composites show bright Fe3O4 cores, gray SiO2 shells and brighter metal shells, due to electron scattering effects and images (Fig. 2g–i) of each composite reveal relatively homogeneous nanoparticle sizes and surface coverage.

Spot analysis using EDS on a single core–shell nanoparticle of an intact composite system reveals the coexistence of Ag/Au and Au/Pd (Fig. S8), although this technique is not quantitatively reliable, because the nanoparticles are present on a three dimensional (3D) architecture and are projected onto the 2D plane, resulting in overlapping. The nanoparticles torn away from d2 by etching reveal distinct bimetallic contrast of the Au cores and the Ag shell in Figs. 3a and b and Fig. S9. However, data acquisition using EDS was difficult due to sample drift. For precise analysis of the core–shell architecture as fixed on the MSM, we prepared an epoxy resin embedding d2 and investigated it after milling with FIB. Milling at room temperature induced serious damage (evaporation) to the Ag shell (Fig. 3c). Nevertheless, the EDS line profile (e) collected along the indicated line in magnified image d indicates that the Au cores were eccentrically surrounded by Ag. We managed to reduce the damage to the Ag shell (Fig. 3f and g) by milling the resin under liquid N2 conditions. The nanoparticles distant from the milled plane show blurred image in Fig. 3f due to defocusing caused by depth. Fortunately, the damage to the Ag shell caused by FIB was not completely even and various sizes of nanoparticles were observed on the surface of MSM. The smaller particles (~5 nm) have a single Au core and the larger particles (~10 nm) have multiple Au cores within each bimetallic nanoparticle. The HRSTEM image (inset of Fig. 3g) of a selected bimetallic nanoparticle shows the Au core surrounded by the Ag shell at atomic resolution with a regular crystalline structure. The core–shell architecture on the outermost surface of MSM, which includes multi-bonds between the Au core and NH2 moieties and embedded core and AP moieties in the shell materials, seems to contribute to the robust fixation of Au–Ag nanoparticles on the MSM. Therefore, the resulting nanosystems have effectively exposed surface areas and the structural robustness required for consistent catalytic activity during repeated cycles, as discussed in the following section.

The reduction of Nip to Amp by NaBH4 was chosen as a model reaction because it has been known to be catalysed by noble metal (Pt, Pd, Au and Ag) nanoparticles2,22,23,33. Due to its much lower cost, Ag is of particular interest. Thus, we briefly investigated the reduction of Nip using d2 and e2 composite system as catalysts. The decrease of the absorption peak at 400 nm, which resulted from the presence of p-nitrophenolate ions, provides direct information about the degree of conversion from Nip to Amp33. Primarily, the reaction without a catalyst system did not proceed at all, even with large excess of NaBH4 (Fig. S10a). However, the d2 or e2 catalysed reactions showed a rapid decrease of the peak at 400 nm (Figs. S10b and c). Assuming that the reduction is a pseudo-first-order reaction with respect to Nip, a linear relationship between ln(Ct/C0) and time t was observed in Fig. 4. The rate constant k at room temperature was 9.5 × 10−2min−1 for d2 and 3.2 × 10−2 and 1.2 × 10−2min−1 for the k1 and k2 regimes, respectively, of e2 in run 1. Interestingly, the e2 system showed two intersecting linear plots and an incomplete reaction, whereas the d2 system showed simple linear plots and complete conversion to Amp, as indicated by their distinct isosbestic points33 (Fig. S10). These trends were consistent up to 5 reaction cycles and were expected for further cycles. The TOF value for d2 in run 1 was 3.5 × 10−3s−1 and the average TOF value for 5 runs was 3.8 × 10−3s−1. The slight variations of k and TOF in d2 are considered experimental errors. Our average TOF value for 5 runs using d2 is definitely improved relative to the reported average (0.97 × 10−3s−1)34 for the first cycles using various concentrations of chitosan-AgNP composites with 4 nm AgNPs. Furthermore, chitosan-AgNP composites showed a decrease of the reaction rate over repeated cycles due to the loss of catalysts during recovery. However, the incomplete reaction and the decrease of k1 and k2 for e2 became more serious as the cycles were repeated. A reasonable explanation for these observatons is that the Au surface is passivated by the NH2 moieties of Amp products and that, under the k2 regime, Nip competes with Amp to occupy the catalyst surface. However, the chemical interaction between Ag and NH2 is sufficiently kinetically labile to complete the reaction. Additionally, most nanoparticles were firmly fixed on the MSM, even after the fifth run, without serious signs of aggregation or morphological change (Fig. S11). Therefore, in this benchmark reaction23 for noble metal nanocatalysts, nAg/Au@MSM was shown to be a promising catalyst and had the lowest cost. More importantly, well-engineered Ag nanoparticles are known to display potential as active catalysts of certain reactions35,36 (e.g., the catalytic oxidation of CO) for which conventional Ag is not regarded as a good catalyst. Therefore, future application studies may increase the utility of the Ag composite system.

The Fe3O4 core, MSM and d2 samples displayed superparamagnetic behavior (Fig. S12), which is essential for a magnetic separation and re-dispersion. The d2 sample was easily separated using an external magnet as shown in the inset of Fig. S12. The saturation magnetization (Ms) of the Fe3O4 core was approximately 70 emug−1, which is in good agreement with the literature value (62~78 emug−1)24, whereas those of MSM and d2 were 22 and 18 emug−1, respectively. The lower Ms of d2 was caused by the heavy silica shell and Au–Ag nanoparticles, but the value was still much higher than that reported for MSM-based Au nanocatalysts with an etched silica shield (6.3 emug−1)21 that were separable from the solution within 3 min in a magnetic field gradient <30 Tm−1.

For practical utilisation of the well-defined nanosystems, scalability is also important. For a scale-up (× 125) synthesis of nAg/Au@MSM (d1~d3) systems, we utilised 125 mL of the Au-seeded MSM with appropriate amounts of the other reagents, which yielded reproducible results. A preliminary study using these systems showed potent antimicrobial effects; these results will be reported elsewhere after further detailed investigation.

Although we utilised MSM as a substrate in most syntheses, industrial scalability is more likely to be achievable for the synthesis utilising SM, because the scale-up synthesis of SM proceeds easily under ambient conditions5 whereas that of MSM is limited by the volume of the hydrothermal container21,24. A representative nAg/Au@SM system utilising SM as a substrate was prepared according to the current SCG strategy and separated by normal centrifugation as described in the methods section and shown in Fig. S13. The surface chemistry of SM and MSM was exactly the same and the synthesis yielded well-defined core–shell bimetallic nanoparticles robustly fixed on the recyclable SM.

In summary, we have demonstrated an innovative strategy of synthesising well-defined Au–Ag core–shell bimetallic nanoparticles robustly fixed on recyclable magnetic silica microspheres so that the cores and aminopropyl moieties are robustly embedded in the shells. These materials have consistently excellent catalytic performances over repeated cycles. The current synthetic strategy was facile, easily scalable and extendible to other important core–shell nanoparticles, such as Au–Pd.

## Methods

AP-MSM and Au seeds were prepared according to the published method21,26,27. The complete details can be found in the SI. Fifteen mililitres of the Au seed solution was mixed with 3 mL of AP-MSM (0.010 g/mL, ~5.7 × 1010particles/mL) to self-assemble the Au seeds on the AP-MSM. The unbound Au seeds were separated using magnetic decantation and the Au-seeded MSM was dispersed in 3 mL of de-ionized water (DW). This solution was used for the following syntheses.

### nAg/Au@MSM (d1~d3)

For a typical synthesis of d1, 1 mL of the Au-seeded MSM was added to a mixture containing 5 mL (10 and 20 mL for d2 and d3) of AgNO3 (0.01 wt%/v in water) and 0.001 mL (0.002 and 0.004 mL for d2 and d3) of NH4OH (30% in water) and stirred for 5 min with a vortex mixer. Then, 0.02 mL (0.02 and 0.04 mL for d2 and d3) of formaldehyde (37% in water) was injected as a reducing reagent and stirred for 30 min with a vortex mixer. After allowing the solution to sit for 1.5 h without perturbation, the d1~d3 samples were rinsed with DW three times using magnetic decantation to remove a small amount of unbound nanoparticles and dispersed in 1 mL of DW. From elemental analysis using AAS and ICP, the concentrations of Au and Ag were 136 and 301, 131 and 576 and 138 and 1128 μg/mL, respectively and the combined weight fraction of Au and Ag in the composite system was 3.85, 6.54 and 10.7% for the respective d1, d2 and d3 systems. Size analysis (Fig. S3) using the TEM images showed 5.8 ± 1.0, 11.4 ± 2.4 and 20.1 ± 4.1 nm particles, respectively. For a scaled-up synthesis of d1~d3, 125 mL of the Au-seeded MSM was used with appropriate amounts of the other reagents and yielded reproducible results.

### nAu/Au@MSM (e1~e3)

First, the Au3+ solution was prepared by mixing 0.025 g of potassium carbonate with 1.5 mL of HAuCl4 (1 wt/v%) in 100 mL of DW. For a typical synthesis of e1, 0.2 mL of the Au-seeded MSM was added to 1 mL (3 and 5 mL for e2 and e3) of Au3+ solution and stirred for 5 min with a vortex mixer. To this solution, 0.02 mL of formaldehyde was injected as a reducing reagent and then, the same process was followed as for d1. Finally, the rinsed e1 ~ e3 samples were dispersed in 0.2 mL of DW. Size analysis using the TEM images revealed 7.2 ± 0.9, 9.9 ± 1.1 and 14.5 ± 12.3 nm (partially merged) particles for the e1, e2 and e3 systems, respectively.

### nPd/Au@MSM (f1~f3)

First, the Pd2+ solution was prepared by dissolving 8.87 mg of PdCl2 in 100 mL of 1 mM HCl solution. To synthesise f1, 0.2 mL of the Au-seeded MSM was added to 2 mL (4 and 8 mL for f2 and f3) of Pd2+ solution and stirred for 5 min using a vortex mixer. To this solution, 0.12 mL (0.24 and 0.48 mL for f2 and f3) of L-ascorbic acid (100 mM) was added as a reducing reagent and then the same process was followed as for d1. Finally, the rinsed f1~f3 samples were dispersed in 0.2 mL of DW. Size analysis using the TEM images showed 3.3 ± 0.4, 5.4 ± 1.0 nm and merged particles for the f1, f2 and f3 systems, respectively.

### nAg/Au@SM

First, 0.080 g of AP-SM (~ 470 nm in diameter) in 1 mL DW was mixed with 10 mL of Au seed solution to self-assemble Au seeds on the AP-SM. Then, the unbound Au seeds were removed using centrifugation (4000 rpm, 10 min) and the Au-seeded SM (precipitate) was dispersed in 3 mL of DW. This solution was added to the mixture of AgNO3 (0.02 g) and NH4OH (30 wt% in water, 0.02 mL) in 100 mL of DW in an ice bath and stirred for 10 min with a magnetic stirrer. Then, 0.04 mL of formaldehyde was slowly injected into the reaction mixture as a reducing reagent and stirred for 30 min in an ice bath. After allowing the solution to sit for 1.5 h without perturbation, the nAg/Au@SM sample was rinsed with DW three times using centrifugation (4000 rpm, 10 min) to remove unbound nanoparticles and dispersed in 50 mL of DW. Then, 25 mL (50%) of the solution was fully dried to give 0.048 g of nAg/Au@SM, with a total estimated yield of 0.096 g.

Catalytic reductions of Nip to Amp by NaBH4 were performed using nAg/Au@MSM (d2) and nAu/Au@MSM (e2) as catalysts. First, 0.1 mL of catalyst solution (~5.7 × 109 composite systems and 0.07 mg of combined weight for Au and Ag in d2) was added to a quartz cuvette containing 2 mL of aqueous Nip (0.2 mM) and 0.2 mL of NaBH4 (30 mM) with stirring and the absorption at 400 nm was recorded every 2 min. Once the reaction was completed, each catalyst was collected by magnetic decantation and thoroughly rinsed with DW using gentle sonication. The recovered catalyst was then reused to initiate the second cycle of the reaction. The same procedure was performed repeatedly up to 5 cycles.

The TEM/STEM/HRTEM images were obtained using an FEI Titan™80-300 (FEI, 300 kV) with a Z-contrast high-angle annular dark field (HAADF) detector or a CM30 (Philips, 200 kV) equipped with EDS (EDAX). The FIB (FEI Helios 600) was applied to mill the epoxy resin embedded with nAg/Au@MSM (d2) at room temperature and at −175 ± 5°C using liquid N2. The SEM images were taken with FEI XL30-ESEM (15 kV) after coating the samples with Pd/Pt for 20 s via ion sputtering (HITACHI, E-1010). The concentration of Ag and Au for the nAg/Au@MSM series were obtained from the Advanced Analysis Center of KIST using an atomic absorption spectrometer (Thermo Electron Corporation, SOLAAR M) and ICP (Varian-710-ES). The extinction data were obtained using a UV-Vis (Perkin Elmer Lambda 25) spectrometer. The magnetic properties were investigated using an alternating gradient magnetometer, Micro Mag 2900 (Princeton Measurement Corporation) by sweeping the external field between −10 to 10 kOe at room temperature.

## References

1. Narayanan, R. & El-Sayed, M. A. Some aspects of colloidal nanoparticle stability, catalytic activity and recycling potential. Top. Catal. 47, 15–21 (2008).

   CAS Article Google Scholar

2. Lu, Y., Mei, Y., Drechsler, M. & Ballauff, M. Thermosensitive core–shell particles as carriers for Ag nanoparticles: modulating the catalytic activity by a phase transition in networks. Angew. Chem., Int. Ed. 45, 813–816 (2006).

   CAS Article Google Scholar

3. Joo, S. H. et al. Thermally stable Pt/mesoporous silica core–shell nanocatalysts for high-temperature reactions. Nature Mater. 8, 126–131 (2009).

   CAS ADS Article Google Scholar

4. Ge, J., Huynh, T., Hu, Y. & Yin, Y. Hierarchical magnetite/silica nanoassemblies as magnetically recoverable catalyst-supports. Nano Lett. 8, 931–934 (2008).

   CAS ADS Article Google Scholar

5. Stöber, W., Fink, A. & Bohn, E. Controlled growth of monodisperse silica spheres in the micron size range. J. Colloid Interface Sci. 26, 62–69 (1968).

   ADS Article Google Scholar

6. Cho, M., Lim, K. & Woo, K. Facile synthesis and optical properties of colloidal silica microspheres encapsulating a quantum dot layer. Chem. Commun. 46, 5584–5586 (2010).

   CAS Article Google Scholar

7. Deng, Y. et al. Multifunctional mesoporous composite microspheres with well-designed nanostructure: a highly integrated catalyst system. J. Am. Chem. Soc. 132, 8466–8473 (2010).

   CAS Article Google Scholar

8. Kim, J. et al. Magnetic nanocomposite spheres decorated with NiO nanoparticles for a magnetically recyclable protein separation system. Adv. Mater. 22, 57–60 (2010).

   CAS Article Google Scholar

9. Serpell, C. J., Cookson, J., Ozkaya, D. & Beer, P. D. Core@shell bimetallic nanoparticle synthesis via anion coordination. Nature Chem. 3, 478–483 (2011).

   CAS ADS Article Google Scholar

10. Alayoglu, S., Nilekar, A. U., Mavrikakis, M. & Eichhorn, B. Ru–Pt core–shell nanoparticles for preferential oxidation of carbon monoxide in hydrogen. Nature Mater. 7, 333–338 (2008).

    CAS ADS Article Google Scholar

11. Enache, D. I. et al. Solvent-free oxidation of primary alcohols to aldehydes using Au-Pd/TiO2 catalysts. Science 311, 362–365 (2006).

    CAS ADS Article Google Scholar

12. Tiruvalam, R. C. et al. Aberration corrected analytical electron microscopy studies of sol-immobilized Au + Pd, Au{Pd} and Pd{Au} catalysts used for benzyl alcohol oxidation and hydrogen peroxide production. Faraday Discuss. 152, 63–68 (2011).

    CAS ADS Article Google Scholar

13. Yang, C.-W. et al. Fabrication of Au–Pd Core–Shell Heterostructures with Systematic Shape Evolution Using Octahedral Nanocrystal Cores and Their Catalytic Activity. J. Am. Chem. Soc. 133, 19993–20000 (2011).

    CAS Article Google Scholar

14. Harada, M., Asakura, K. & Toshima, N. Catalytic Activity and Structural Analysis of Polymer-Protected Au/Pd Bimetallic Clusters Prepared by the Successive Reduction of HAuCl4 and PdCl2 . J. Phys. Chem. 97, 5103–5114 (1993).

    CAS Article Google Scholar

15. Jiang, H.-L. et al. Synergistic Catalysis of Au@Ag Core–Shell Nanoparticles Stabilized on Metal-Organic Framework. J. Am. Chem. Soc. 133, 1304–1306 (2011).

    CAS Article Google Scholar

16. Zhang, X. & Su, Z. Polyelectrolyte-Multilayer-Supported Au@Ag Core-Shell Nanoparticles with High Catalytic Activity. Adv. Mater. 24, 4574–4577 (2012).

    CAS Article Google Scholar

17. Shylesh, S., Schünemann, V. & Thiel, W. R. Magnetically Separable Nanocatalysts: Bridges between Homogeneous and Heterogeneous Catalysis. Angew. Chem., Int. Ed. 49, 3428–3459 (2010).

    CAS Article Google Scholar

18. Polshettiwar, V. et al. Magnetically Recoverable Nanocatalysts. Chem. Rev. 111, 3036–3075 (2011).

    CAS Article Google Scholar

19. Sárkány, A., Geszti, O. & Sáfrán, G. Preparation of Pdshell-Aucore/SiO2 catalyst and catalytic activity for acetylene hydrogenation. Applied Catalysis A: General 350, 157–163 (2008).

    Article Google Scholar

20. Kim, J. et al. Generalized Fabrication of Multifunctional Nanoparticle Assemblies on Silica Spheres. Angew. Chem., Int. Ed. 45, 4789–4793 (2006).

    CAS Article Google Scholar

21. Ge, J., Zhang, Q., Zhang, T. & Yin, Y. Core-satellite nanocomposite catalysts protected by a porous silica shell: controllable reactivity, high stability and magnetic recyclability. Angew. Chem., Int. Ed. 47, 8924–8928 (2008).

    CAS Article Google Scholar

22. Mie, Y., Lu, Y., Polzer, F. & Ballauff, M. Catalytic activity of palladium nanoparticles encapsulated in spherical polyelectrolyte brushes and core–shell microgels. Chem. Mater. 19, 1062–1069 (2007).

    Article Google Scholar

23. Zhang, H., Li, X. & Chen, G. Ionic liquid-facilitated synthesis and catalytic activity of highly dispersed Ag nanoclusters supported on TiO2 . J. Mater. Chem. 19, 8223–8231 (2009).

    CAS Article Google Scholar

24. Liu, J. et al. Highly water-dispersible biocompatible magnetite particles with low cytotoxicity stabilized by citrate groups. Angew. Chem., Int. Ed. 48, 5875–5879 (2009).

    CAS Article Google Scholar

25. Kim, J.-H., Chung, H.-W. & Lee, T. R. Preparation and characterization of palladium shells with gold and silica cores. Chem. Mater. 18, 4115–4120 (2006).

    CAS Article Google Scholar

26. Duff, D. G. & Baiker, A. A new hydrosol of gold clusters. 1. Formation and particle size variation. Langmuir 9, 2301–2309 (1993).

    CAS Article Google Scholar

27. Duff, D. G. & Baiker, A. A new hydrosol of gold clusters. 2. A comparison of some different measurement techniques. Langmuir 9, 2310–2317 (1993).

    CAS Article Google Scholar

28. Kumar, A., Joshi, H., Pasricha, R., Mandale, A. B. & Sastry, M. Phase transfer of silver nanoparticles from aqueous to organic solutions using fatty amine molecules. J. Colloid Interface Sci. 264, 396–401 (2003).

    CAS ADS Article Google Scholar

29. Leff, D. V., Brandt, L. & Heath, J. R. Synthesis and characterization of hydrophobic, organically-soluble gold nanocrystals functionalized with primary amines. Langmuir 12, 4723–4730 (1996).

    CAS Article Google Scholar

30. Okamoto, H. Phase Diagrams for Binary Alloys (ASM International, Materials Park, OH, 2000).

31. Sato, R., Kanehara, M. & Teranishi, T. Homoepitaxial size control and large-scale synthesis of highly monodisperse amine-protected palladium nanoparticles. Small 4, 469–473 (2011).

    Article Google Scholar

32. Hiramatsu, H. & Osterloh, F. E. pH-controlled assembly and disassembly of electrostatically linked CdSe-SiO2 and Au-SiO2 nanoparticle clusters. Langmuir 19, 7003–7011 (2003).

    CAS Article Google Scholar

33. Wunder, S., Polzer, F., Lu, Y., Mei, Y. & Ballauff, M. Kinetic analysis of catalytic reduction of 4-nitrophenol by metallic nanoparticles immobilized in spherical polyelectrolyte brushes. J. Phys. Chem. C 114, 8814–8820 (2010).

    CAS Article Google Scholar

34. Murugadoss, A. & Chattopadhyay, A. A ‘green’ chitosan–silver nanoparticle composite as a heterogeneous as well as micro-heterogeneous catalyst. Nanotechnology 19, 015603 (9pp) (2008).

35. Falsig, H. et al. Trends in the catalytic CO oxidation activity of nanoparticles. Angew. Chem., Int. Ed. 47, 4835–4839 (2008).

    CAS Article Google Scholar

36. Liu, H. Y., Ma, D., Blackley, R. A., Zhou, W. Z. & Bao, X. H. Highly active mesostructured silica hosted silver catalysts for CO oxidation using the one-pot synthesis approach. Chem. Commun. 2677–2679 (2008).

Download references

## Acknowledgements

This research was supported by Future-based Technology Development Program (Green Nano Technology Development Program) through the National Research Foundation of Korea (NRF) funded by the Ministry of Education, Science and Technology (grant number 2012-0009627) and Future Key Technology Program of Korea Institute of Science and Technology.

## Author information

### Affiliations

1. Molecular Recognition Research Center, Korea Institute of Science and Technology, P. O. Box 131, Seoul, 130-650, Cheongryang, Korea

   Hye Hun Park & Kyoungja Woo

2. Advanced Analysis Center, Korea Institute of Science and Technology, P. O. Box 131, Seoul, 130-650, Cheongryang, Korea

   Jae-Pyoung Ahn

Authors

1. Hye Hun Park
   View author publications

   You can also search for this author in PubMed Google Scholar

2. Kyoungja Woo
   View author publications

   You can also search for this author in PubMed Google Scholar

3. Jae-Pyoung Ahn
   View author publications

   You can also search for this author in PubMed Google Scholar

### Contributions

K.W. conceived the project. K.W. and H.H.P. designed the experiments. H.H.P. conducted the experiments. J.-P.A. performed Z-contrast HAADF-STEM imaging. All authors contributed to analysing the data. K.W. and H.H.P. wrote the paper.

## Ethics declarations

### Competing interests

The authors declare no competing financial interests.

## Electronic supplementary material

### Supplementary InformationSupplementary experimental section and data

## Rights and permissions

This work is licensed under a Creative Commons Attribution-NonCommercial-NoDerivs 3.0 Unported License. To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-nd/3.0/

Reprints and Permissions

## About this article

### Cite this article

Park, H., Woo, K. & Ahn, JP. Core–Shell Bimetallic Nanoparticles Robustly Fixed on the Outermost Surface of Magnetic Silica Microspheres. Sci Rep 3, 1497 (2013). https://doi.org/10.1038/srep01497

Download citation

- Received: 30 July 2012

- Accepted: 04 March 2013

- Published: 20 March 2013

- DOI: https://doi.org/10.1038/srep01497

## Further reading

- ### Structural, optical and electrical behavior of ZnO@Ag core–shell nanocomposite synthesized via novel plasmon-green mediated approach

  - C. Vivek
  - , B. Balraj
  - & S. Thangavel

  Journal of Materials Science: Materials in Electronics (2019)

- ### Facile polystyrene/ZnO/Fe3O4 nanocomposites prepared via a hydrothermal approach for enhancement of MB dye degradation

  - R. Suganya
  - & N. Krishnaveni

  Research on Chemical Intermediates (2019)

- ### Synthesis and photoluminescence properties of silica-modified SiO 2 @ANA-Si-Tb@SiO 2 , SiO 2 @ANA-Si-Tb-L@SiO 2 core–shell–shell nanostructured composites

  - Lina Feng
  - , Wenxian Li
  - , Jinrong Bao
  - , Yushan Zheng
  - , Yilian Li
  - , Yangyang Ma
  - , Kuisuo Yang
  - , Yan Qiao
  - & Anping Wu

  Royal Society Open Science (2019)

- ### Synthesis and Luminescence Properties of Core-Shell-Shell Composites: SiO2@PMDA-Si-Tb@SiO2 and SiO2@PMDA-Si-Tb-phen@SiO2

  - Lina Feng
  - , Wenxian Li
  - , Jinrong Bao
  - , Yushan Zheng
  - , Yilian Li
  - , Yangyang Ma
  - , Kuisuo Yang
  - , Yan Qiao
  - & Anping Wu

  Nanomaterials (2019)

- ### Studies on structural, optical and thermal properties of Fe3O4 (NR)/ZrO2 CSNCs synthesized via green approach for photodegradation of dyes

  - E. Nandhakumar
  - , P. Priya
  - , R. Rajeswari
  - , V. Aravindhan
  - , A. Sasikumar
  - & N. Senthilkumar

  Research on Chemical Intermediates (2019)

## Comments

By submitting a comment you agree to abide by our Terms and Community Guidelines. If you find something abusive or that does not comply with our terms or guidelines please flag it as inappropriate.

Download PDF

Sign up for the Nature Briefing newsletter — what matters in science, free to your inbox daily.

Email address
I agree my information will be processed in accordance with the Nature and Springer Nature Limited Privacy Policy.
Get the most important science stories of the day, free in your inbox. Sign up for Nature Briefing